==> ejc-metadata-api-3.0.0-20200604.084553-50-sources.jar: com/ejianc/foundation/metadata/vo/MdClassVO.java <==
package com.ejianc.foundation.metadata.vo;

import java.util.ArrayList;
import java.util.List;

import com.ejianc.framework.skeleton.template.BaseVO;

public class MdClassVO extends BaseVO {

	private static final long serialVersionUID = 1L;

	private Long id; // 主键ID

	private String entityName; // 实体名称

	private String displayName; // 显示名称

	private String entityFullName; // 实体全名

	private String tableName; // 表名称

	private boolean mainFlag; // 是否是主实体

	private Long parentId; // 弱关联时，父实体ID

	private String parentName;// 弱关联时，父实体name

	private Long projectId; // 工程ID

	private Long tenantId; // 租户ID
	
	private String refCode;	//参照编码
	
	private List<MdAttributeVO> attributos = new ArrayList<>();	//	属性表集合
	
	private List<MdRelationVO> relations = new ArrayList<>();	//	关系表集合
	
	private Integer dr;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getEntityName() {
		return entityName;
	}

	public void setEntityName(String entityName) {
		this.entityName = entityName;
	}

	public String getDisplayName() {
		return displayName;
	}

	public void setDisplayName(String displayName) {
		this.displayName = displayName;
	}

	public String getEntityFullName() {
		return entityFullName;
	}

	public void setEntityFullName(String entityFullName) {
		this.entityFullName = entityFullName;
	}

	public String getTableName() {
		return tableName;
	}

	public void setTableName(String tableName) {
		this.tableName = tableName;
	}

	public boolean getMainFlag() {
		return mainFlag;
	}

	public void setMainFlag(boolean mainFlag) {
		this.mainFlag = mainFlag;
	}

	public Long getParentId() {
		return parentId;
	}

	public void setParentId(Long parentId) {
		this.parentId = parentId;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public Long getTenantId() {
		return tenantId;
	}

	public void setTenantId(Long tenantId) {
		this.tenantId = tenantId;
	}

	public List<MdAttributeVO> getAttributos() {
		return attributos;
	}

	public void setAttributos(List<MdAttributeVO> attributos) {
		this.attributos = attributos;
	}

	public String getRefCode() {
		return refCode;
	}

	public void setRefCode(String refCode) {
		this.refCode = refCode;
	}

	public String getParentName() {
		return parentName;
	}

	public void setParentName(String string) {
		this.parentName = string;
	}

	public Integer getDr() {
		return dr;
	}

	public void setDr(Integer dr) {
		this.dr = dr;
	}

	public List<MdRelationVO> getRelations() {
		return relations;
	}

	public void setRelations(List<MdRelationVO> relations) {
		this.relations = relations;
	}

}

==> ejc-metadata-api-3.0.0-20200904.104216-92-sources.jar: com/ejianc/foundation/metadata/vo/MdClassVO.java <==
package com.ejianc.foundation.metadata.vo;

import java.util.ArrayList;
import java.util.List;

import com.ejianc.framework.skeleton.template.BaseVO;

public class MdClassVO extends BaseVO {

	private static final long serialVersionUID = 1L;

	private Long id; // 主键ID

	private String entityName; // 实体名称

	private String displayName; // 显示名称

	private String entityFullName; // 实体全名

	private String tableName; // 表名称

	private boolean mainFlag; // 是否是主实体

	private Long parentId; // 弱关联时，父实体ID

	private String parentName;// 弱关联时，父实体name

	private Long projectId; // 工程ID

	private Long tenantId; // 租户ID
	
	private String refCode;	//参照编码
	
	private List<MdAttributeVO> attributos = new ArrayList<>();	//	属性表集合
	
	private List<MdRelationVO> relations = new ArrayList<>();	//	关系表集合
	
	private Integer dr;

	//打印临时使用字段
	private String dataBaseName; //数据库名

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getEntityName() {
		return entityName;
	}

	public void setEntityName(String entityName) {
		this.entityName = entityName;
	}

	public String getDisplayName() {
		return displayName;
	}

	public void setDisplayName(String displayName) {
		this.displayName = displayName;
	}

	public String getEntityFullName() {
		return entityFullName;
	}

	public void setEntityFullName(String entityFullName) {
		this.entityFullName = entityFullName;
	}

	public String getTableName() {
		return tableName;
	}

	public void setTableName(String tableName) {
		this.tableName = tableName;
	}

	public boolean getMainFlag() {
		return mainFlag;
	}

	public void setMainFlag(boolean mainFlag) {
		this.mainFlag = mainFlag;
	}

	public Long getParentId() {
		return parentId;
	}

	public void setParentId(Long parentId) {
		this.parentId = parentId;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public Long getTenantId() {
		return tenantId;
	}

	public void setTenantId(Long tenantId) {
		this.tenantId = tenantId;
	}

	public List<MdAttributeVO> getAttributos() {
		return attributos;
	}

	public void setAttributos(List<MdAttributeVO> attributos) {
		this.attributos = attributos;
	}

	public String getRefCode() {
		return refCode;
	}

	public void setRefCode(String refCode) {
		this.refCode = refCode;
	}

	public String getParentName() {
		return parentName;
	}

	public void setParentName(String string) {
		this.parentName = string;
	}

	public Integer getDr() {
		return dr;
	}

	public void setDr(Integer dr) {
		this.dr = dr;
	}

	public List<MdRelationVO> getRelations() {
		return relations;
	}

	public void setRelations(List<MdRelationVO> relations) {
		this.relations = relations;
	}

	public String getDataBaseName() {
		return dataBaseName;
	}

	public void setDataBaseName(String dataBaseName) {
		this.dataBaseName = dataBaseName;
	}
}
